@@ -24,9 +24,14 @@ def main():
     raise BadRequest
 
 
-def serve() -> None:
+# added because of wsgi
+def initialize() -> None:
     logging.initialize()
     load_dotenv()
+
+
+def serve() -> None:
+    initialize()
     app.run(port=5500)
 
 
